//
// Test program for STR #3503
//
// Build: fltk-config --compile fl_choice-crash.cxx
//
// Test: run program and open the Fl_Choice menu within 4 seconds.
//
// Expected behavior: The Fl_Choice widget will be deleted 4 seconds after
// the start of the program, no matter whether you open the Fl_Choice menu
// or not.
//
// Behavior before fix: If you open the menu within 4 seconds and move the
// mouse or click on an item the program will either display garbage in the
// choices or crash (Linux: segmentation fault).
//

#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Choice.H>

// timer callback to delete the Fl_Choice widget

void rem_cb(void *p) {
  Fl_Widget *w = (Fl_Widget *)p;
  Fl_Window *win = w->window();
  delete w;
  if (win)
    win->redraw();
}

// main program
int main(int argc, char **argv) {
  Fl_Window *window = new Fl_Window(340,260);
  Fl_Choice *ch = new Fl_Choice(20,40,300,30,
	"\nPlease open the menu within 4 seconds after the program "
	"was started!\n\n"
	"The Fl_Choice widget will be\ndeleted after 4 seconds.");
  ch->box(FL_DOWN_BOX);
  ch->align(FL_ALIGN_BOTTOM | FL_ALIGN_WRAP);
  ch->add("please make your choice");
  ch->add("good");
  ch->add("bad");
  ch->add("awesome");
  ch->value(0);
  window->end();
  window->show(argc, argv);
  Fl::add_timeout(4.0, rem_cb, ch);
  return Fl::run();
}

//
// End of test program
//
